==> qmmp-2.3.0.tar.bz2: qmmp-2.3.0/src/plugins/General/taskbar/translations/taskbar_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>TaskbarFactory</name>
    <message>
        <location filename="../taskbarfactory.cpp" line="28"/>
        <source>Taskbar Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="49"/>
        <source>About Taskbar Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="50"/>
        <source>Qmmp Taskbar Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="51"/>
        <source>This plugin adds support for progress indicator in the Windows taskbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="53"/>
        <source>Based on QtWinExtras module of the Qt Toolkit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="54"/>
        <source>QtWinExtras developers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="55"/>
        <source>Ivan Vizir &lt;define-true-false@yandex.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="56"/>
        <source>The Qt Company Ltd.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_2.3.1.orig.tar.bz2: qmmp-2.3.1/src/plugins/General/taskbar/translations/taskbar_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>TaskbarFactory</name>
    <message>
        <location filename="../taskbarfactory.cpp" line="28"/>
        <source>Taskbar Plugin</source>
        <translation>任务栏插件</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="49"/>
        <source>About Taskbar Plugin</source>
        <translation>关于任务栏插件</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="50"/>
        <source>Qmmp Taskbar Plugin</source>
        <translation>Qmmp 任务栏插件</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="51"/>
        <source>This plugin adds support for progress indicator in the Windows taskbar</source>
        <translation>此插件为 Windows 任务栏添加进度指示器支持</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="53"/>
        <source>Based on QtWinExtras module of the Qt Toolkit</source>
        <translation>基于 Qt 工具包的 QtWinExtras 模块</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="54"/>
        <source>QtWinExtras developers:</source>
        <translation>QtWinExtras 开发者：</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="55"/>
        <source>Ivan Vizir &lt;define-true-false@yandex.com&gt;</source>
        <translation>Ivan Vizir &lt;define-true-false@yandex.com&gt;</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="56"/>
        <source>The Qt Company Ltd.</source>
        <translation>Qt 公司 Ltd.</translation>
    </message>
</context>
</TS>
